import c4d
import maxon

def GetCameraName(data):
	"""
	A token that looks for the active camera name and reformats the name
	to be all uppercase for the filename.

	Works with single render when just rendering straight to viewport with
	current active settings, but does not work when rendering with
	Takes that have different settings than the currently active settings.
	"""
	doc = c4d.documents.GetActiveDocument()
	bd = doc.GetRenderBaseDraw()
	sceneCam = bd.GetSceneCamera(doc)
	camName = sceneCam.GetName()
	return camName.upper()


def GetResolutionActive(data):
	"""
	A token that looks for the active rendering setting's output width
	and determines whether the filename should be "highRes"or "lowRes"
	based on the width.

	Works with single render when just rendering straight to viewport
	with current active settings, but does not work when rendering with
	Takes that have different settings than the currently active settings.
	"""
	doc = c4d.documents.GetActiveDocument()
	renderData = doc.GetActiveRenderData()
	renderResX = round(renderData[c4d.RDATA_XRES])
	if renderResX >= 1920:
		return "activeDocHighRes"
	else:
		return "activeDocLowRes"


def GetResolutionTakes(data):
	"""
	An alternate version of the GetResolutionActive(data) above with an
	attempt to use Take Data, but seems I might not be writing this correctly?
	Still doesn't update correctly when rendering with Takes.
	"""
	doc = c4d.documents.GetActiveDocument()

	takeData = doc.GetTakeData()
	if takeData is None:
		return

	take = takeData.GetCurrentTake()
	if take is None:
		return

	renderData = take.GetRenderData(takeData)
	renderResX = round(renderData[c4d.RDATA_XRES])

	c4d.EventAdd()

	if renderResX >= 1920:
		return "takeHighRes"
	else:
		return "takeLowRes"

#----------------------------------------------------------------------------------------------------------------------------------------
# Register Tokens
#----------------------------------------------------------------------------------------------------------------------------------------
if __name__=="__main__":
	for registeredToken in c4d.modules.tokensystem.GetAllTokenEntries():
		if registeredToken.get("_token") in ["camUppercase", "lowHighResActive", "lowHighResTakes"]:
			exit()

	# Filename Parsed Tokens
	c4d.plugins.RegisterToken("camUppercase","[TEST] Uppercase Cam Name", "CAMNAME", GetCameraName)
	c4d.plugins.RegisterToken("lowHighResActive","[TEST] Low/High Resolution [Active Doc]", "lowRes / highRes", GetResolutionActive)
	c4d.plugins.RegisterToken("lowHighResTakes","[TEST] Low/High Resolution [Current Take]", "lowRes / highRes", GetResolutionTakes)